/**
 * Various of endpoint the CoinMarketCap API.
 */
export declare const endpoints: {
    /** Various CoinMarketCap cryptocurrency endpoints. */
    crypto: {
        /** The CoinMarketCap cryptocurrency ID map endpoint. */
        map: string;
        /** The cryptocurrency metadata endpoint. */
        metadata: string;
        /** The latest cryptocurrency listings endpoint. */
        listings: string;
        /** The new cryptocurrency listings endpoint. */
        listingsNew: string;
        /** The historical cryptocurrency listings endpoint. */
        listingsHistorical: string;
        /** The latest cryptocurrency quotes endpoint. */
        quotes: string;
        /** The historical cryptocurrency quotes endpoint. */
        quotesHistorical: string;
        /** The historical cryptocurrency quotes (version 3) endpoint. */
        quotesHistoricalV3: string;
        /** The latest cryptocurrency market pairs endpoint. */
        marketPairs: string;
        /** The latest cryptocurrency OHLCV endpoint. */
        ohlcv: string;
        /** The historical cryptocurrency OHLCV endpoint. */
        ohlcvHistorical: string;
        /** The latest cryptocurrency price performance statistics endpoint. */
        performance: string;
        /** The cryptocurrency categories endpoint. */
        categories: string;
        /** The cryptocurrency category endpoint. */
        category: string;
        /** The cryptocurrency airdrops endpoint. */
        airdrops: string;
        /** The cryptocurrency airdrop endpoint. */
        airdrop: string;
        /** The latest cryptocurrencies trending endpoint. */
        trending: string;
        /** The most visited trending cryptocurrencies endpoint. */
        mostVisited: string;
        /** The trending gainers and losers of cryptocurrencies endpoint. */
        gainersLosers: string;
    };
    /** Various decentralized exchange (DEX) endpoints. */
    dex: {
        /** The all networks of DEXes endpoint. */
        map: string;
        /** The latest listings of DEXes endpoint. */
        listings: string;
        /** The metadata of DEXes endpoint. */
        metadata: string;
        /** The latest listings of trading pairs DEXes endpoint. */
        pairs: string;
        /** The latest quotes of trading pairs DEXes endpoint. */
        quotes: string;
        /** The latest DEXes OHLCV quotes endpoint. */
        ohlcv: string;
        /** The historical DEXes OHLCV quotes endpoint. */
        ohlcvHistorical: string;
        /** The latest 100 DEXes trades endpoint. */
        trades: string;
    };
    /** Various CoinMarketCap exchange endpoints. */
    cex: {
        /** The CoinMarketCap exchange ID map endpoint. */
        map: string;
        /** The exchange metadata endpoint. */
        metadata: string;
        /** The latest exchange listings endpoint. */
        listings: string;
        /** The latest exchange quotes endpoint. */
        quotes: string;
        /** The historical exchange quotes endpoint. */
        quotesHistorical: string;
        /** The latest market pairs on exchanges endpoint. */
        pairs: string;
        /** The exchange assets endpoint. */
        assets: string;
    };
    /** Various global metrics and indices endpoints. */
    metric: {
        /** The latest global metrics quotes endpoint. */
        quotes: string;
        /** The historical global metrics quotes endpoint. */
        quotesHistorical: string;
        /** The latest CoinMarketCap 100 Index endpoint. */
        index: string;
        /** The historical CoinMarketCap 100 Index endpoint. */
        indexHistorical: string;
        /** The latest CoinMarketCap Fear and Greed Index endpoint. */
        fearAndGreed: string;
        /** The historical CoinMarketCap Fear and Greed Index endpoint. */
        fearAndGreedHistorical: string;
        /** The latest Blockchain Statistics endpoint. */
        blockchainStats: string;
    };
    /** Various community content and trends endpoints. */
    community: {
        /** The latest content endpoint. */
        news: string;
        /** The top posts endpoint. */
        top: string;
        /** The latest posts endpoint. */
        latest: string;
        /** The comments on posts endpoint. */
        comments: string;
        /** The trending community topics endpoint. */
        trendingTopic: string;
        /** The trending community tokens endpoint. */
        trendingToken: string;
    };
    /** Various tools & other CoinMarketCap API endpoints. */
    misc: {
        /** The list of fiat currencies endpoint. */
        fiat: string;
        /** The price conversion tool endpoint. */
        priceConversion: string;
        /** The usage statistics of the API key endpoint. */
        usageStats: string;
    };
};
export default endpoints;
